# meggie\_fooof

meggie\_fooof is a plugin for meggie that provides basic interface to FOOOF functionality.

## Installation

1. Activate the meggie environment
1. Then install: python -m pip install meggie\_fooof

## Usage

If everything went fine, meggie should now recognize the plugin and you can enable it from the settings.

